@@ -87,7 +87,7 @@ class DataFrame(robjects.DataFrame):
 
     def collect(self, *args, **kwargs):
         cls = type(self)
-        return cls(rfunc(self, *args, **kwargs))
+        return cls(dplyr.collect(self, *args, **kwargs))
         
 class GroupedDataFrame(robjects.DataFrame):
     pass
@@ -106,12 +106,17 @@ DataFrame.right_join = _wrap2(dplyr.right_join, None)
 DataFrame.full_join = _wrap2(dplyr.full_join, None)
 DataFrame.semi_join = _wrap2(dplyr.semi_join, None)
 DataFrame.anti_join = _wrap2(dplyr.anti_join, None)
+DataFrame.union = _wrap2(dplyr.union, None)
+DataFrame.intersect = _wrap2(dplyr.intersect, None)
+DataFrame.setdiff = _wrap2(dplyr.setdiff, None)
+
 DataFrame.sample_n = _wrap(dplyr.sample_n, None)
 DataFrame.sample_frac = _wrap(dplyr.sample_frac, None)
 DataFrame.slice = _wrap(dplyr.slice_, None)
 
 GroupedDataFrame.summarize = _wrap(dplyr.summarize_, DataFrame)
 GroupedDataFrame.summarise = GroupedDataFrame.summarize
+GroupedDataFrame.ungroup = _wrap(dplyr.ungroup, DataFrame)
 
 arrange = _make_pipe(dplyr.arrange_, DataFrame)
 distinct = _make_pipe(dplyr.distinct_, DataFrame)
@@ -129,6 +134,9 @@ right_join = _make_pipe2(dplyr.right_join, DataFrame)
 full_join = _make_pipe2(dplyr.full_join, DataFrame)
 semi_join = _make_pipe2(dplyr.semi_join, DataFrame)
 anti_join = _make_pipe2(dplyr.anti_join, DataFrame)
+union = _make_pipe2(dplyr.union, DataFrame)
+intersect = _make_pipe2(dplyr.intersect, DataFrame)
+setdiff = _make_pipe2(dplyr.setdiff, DataFrame)
 sample_n = _make_pipe(dplyr.sample_n, DataFrame)
 sample_frac = _make_pipe(dplyr.sample_frac, DataFrame)
 slice = _make_pipe(dplyr.slice_, DataFrame)
