@@ -158,10 +158,18 @@ class VectorOperationsDelegator(object):
         res = globalenv_ri.get("^")(self._parent, conversion.py2ri(x))
         return conversion.ri2ro(res)
 
-    def __div__(self, x):
-        res = globalenv_ri.get("/")(self._parent, conversion.py2ri(x))
-        return conversion.ri2ro(res)
-
+    if sys.version_info[0] == 2:
+        def __div__(self, x):
+            res = globalenv_ri.get("/")(self._parent, conversion.py2ri(x))
+            return conversion.ri2ro(res)
+    else:
+        def __floordiv__(self, x):
+            res = globalenv_ri.get("%/%")(self._parent, conversion.py2ri(x))
+            return conversion.ri2ro(res)
+        def __truediv__(self, x):
+            res = globalenv_ri.get("/")(self._parent, conversion.py2ri(x))
+            return conversion.ri2ro(res)        
+        
     def __divmod__(self, x):
         res = globalenv_ri.get("%%")(self._parent, conversion.py2ri(x))
         return conversion.ri2ro(res)
@@ -317,7 +325,9 @@ class Vector(RObjectMixin, SexpVector):
             return res
 
         l = len(self)
-        if l < 7:
+        if l == 0:
+            s = '[]'
+        elif l < 7:
             s = '[' + \
                 ', '.join((p_str(elt, max_width = math.floor(52 / l)) for elt in self[ : 8])) +\
                 ']'
@@ -473,17 +483,24 @@ class FactorVector(IntVector):
     def NAvalue(self):
         return rinterface.NA_Integer
     
-    def __init__(self, obj, levels = rinterface.MissingArg,
+    def __init__(self, obj,
+                 levels = rinterface.MissingArg,
                  labels = rinterface.MissingArg,
                  exclude = rinterface.MissingArg,
                  ordered = rinterface.MissingArg):
         if not isinstance(obj, Sexp):
             obj = StrSexpVector(obj)
-        res = self._factor(obj,
-                           levels = levels,
-                           labels = labels,
-                           exclude = exclude,
-                           ordered = ordered)
+        if ('factor' in obj.rclass) and \
+           all(p is rinterface.MissingArg for p in (labels,
+                                                    exclude,
+                                                    ordered)):
+            res = obj
+        else:
+            res = self._factor(obj,
+                               levels = levels,
+                               labels = labels,
+                               exclude = exclude,
+                               ordered = ordered)
         self.__sexp__ = res.__sexp__
         self.ro = VectorOperationsDelegator(self)
         self.rx = ExtractDelegator(self)
